Line plot showing the relationship between the criterion used to assess column position
balance and the number of iterations in the column position balancing routine.
Usage
cp.scree(des)
Arguments
des
An R object containing the results from a call to tradeoff.des.
Value
A line plot showing the relationship between the criterion used to assess column position
balance and the number of iterations in the column position balancing routine.
Details
Column position balancing is the most computationally intensive process in calls to tradeoff.des.
The number of iterations required for this step is determined by the Rc argument in that function
which defaults to the larger of 1,000 or 10 x the number of rows in the design. Large design problems
may require a larger number of iterations to achieve optimal column position balance. The plot generated by
this function can help to assess whether additional Rc iterations would lead to better column
position balance.