Learn R Programming

choiceDes (version 0.9-1)

dcm.design.gencand: Full factorial design

Description

Generate a full factorial design set given a vector of factor lengths.

Usage

dcm.design.gencand(levs)

Arguments

levs

A vector of factor lengths.

Value

A data frame of factors in a full factorial design.

Details

This function can be used in concert with dcm.design.cand when the candidate set must be manipulated or restricted before generating a fractional factorial design. Generate the full factorial design using this function, manipulate it with appropriate R code. Or export the candidate generated by this function to Excel or another application, and save the result as a tab-delimited text file that can be imported as part of the call to dcm.design.cand.

Use dcm.design by itself to generate fractional factorial designs from full factorial candidate sets that do not require further manipulation. The required candidate set(s) are generated internally by that function given a vector of factor lengths as input.

See Also

gen.factorial

Examples

Run this code
# NOT RUN {
levs <- c(3,4,3,2) 
cand <- dcm.design.gencand(levs)
# }

Run the code above in your browser using DataLab