Learn R Programming

choiceDes (version 0.9-3)

optFederovC: Optimal design

Description

INTERNAL: Simplified wrapper for calculating exact algorithmic designs using Federov's exchange algorithm. Based on optFederov in the AlgDesign package.

Usage

optFederovC(modelData, nTrials, nRepeats=5)

Arguments

modelData

The candidate list. A matrix or data frame describing the variables. If a matrix is input and the columns are not named, they will be assigned names X1, X2, etc. Permitted data types include factors or levels- or effects-coded designs.

nTrials

The number of trials in the final design.

nRepeats

The number of times the whole process is repeated.

Value

D

The kth root of the generalized variance: det(M)^(1/k), where det(M) is the determinant of the normalized dispersion matrix, or m=Z'Z/n, where Z=X[rows,].

A

The average coefficient variance: trace(M')/k, where M' is the inverse of M.

Ge

The minimax normalized variance over X, expressed as an efficiency with respect to the optimal approximate theory design. It is defined as k/max(d), where max(d) is the maximum normalized variance over X, or the maximum of x'(M')x, over all rows x' of X.

Dea

A lower bound on D efficiency for approximate theory designs. It is equal to exp(1-1/Ge).

design

The design.

rows

A numerical vector of the design row numbers from modelData.

Details

Generates exact algorithmic designs using Federov's exchange algorithm, and optimizing the D criterion. See optFederov for algorithmic details. A vignette is also available by typing vignette("AlgDesign").

Input data, i.e., modelData, must be of a form that model.matrix(~., modelData results in an effects-coded design or candidate set.

References

Wheeler, R.E. (2004). optFederov. AlgDesign. The R project for statistical computing. (http://www.r-project.org).

Examples

Run this code
# NOT RUN {
##INTERNAL USE ONLY
# }

Run the code above in your browser using DataLab